@@ -1,23 +1,11 @@
 /* This file is part of the KDE project
-   Copyright (C) 2015 Luiz Romário Santana Rios <luizromario@gmail.com>
+   SPDX-FileCopyrightText: 2015 Luiz Romário Santana Rios <luizromario@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kcompressiondevicetest.h"
+#include "kcompressiondevice_p.h"
 
 #include <config-compression.h>
 
@@ -190,3 +178,39 @@ void KCompressionDeviceTest::testWriteErrorOnClose()
     // THEN
     QCOMPARE(int(dev.error()), int(QFileDevice::WriteError));
 }
+
+void KCompressionDeviceTest::testSeekReadUncompressedBuffer_data()
+{
+    QTest::addColumn<int>("dataSize");
+    QTest::addColumn<int>("realDataPos");
+    QTest::newRow("1.5buffer") << BUFFER_SIZE + BUFFER_SIZE / 2 << BUFFER_SIZE;
+    QTest::newRow("5seekbuffer") << 5 * SEEK_BUFFER_SIZE << 4 * SEEK_BUFFER_SIZE;
+}
+
+void KCompressionDeviceTest::testSeekReadUncompressedBuffer()
+{
+    QFETCH(int, dataSize);
+    QFETCH(int, realDataPos);
+
+    QByteArray ba(dataSize, 0);
+
+    // all data is zero except after realDataPos that it's 0 to 9
+    for (int i = 0; i < 10; ++i) {
+        ba[realDataPos + i] = i;
+    }
+
+    QBuffer b;
+    b.setData(ba);
+    QVERIFY(b.open(QIODevice::ReadOnly));
+
+    KCompressionDevice kcd(&b, false, KCompressionDevice::GZip);
+    QVERIFY(kcd.open(QIODevice::ReadOnly));
+    QVERIFY(kcd.seek(realDataPos));
+
+    // the 10 bytes after realDataPos should be 0 to 9
+    const QByteArray kcdData = kcd.read(10);
+    QCOMPARE(kcdData.size(), 10);
+    for (int i = 0; i < kcdData.size(); ++i) {
+        QCOMPARE(kcdData[i], i);
+    }
+}
