@@ -7,7 +7,6 @@
 #include "kbzip2filter.h"
 #include "loggingcategory.h"
 
-#include <config-compression.h>
 
 #if HAVE_BZIP2_SUPPORT
 
@@ -28,7 +27,7 @@ extern "C" {
 
 #include <QDebug>
 
-#include <qiodevice.h>
+#include <QIODevice>
 
 // For docu on this, see /usr/doc/bzip2-0.9.5d/bzip2-0.9.5d/manual_3.html
 
